@@ -23,6 +23,7 @@
 #include "../config.h"
 #endif
 
+#include <endian.h>
 #include <getopt.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -82,19 +83,49 @@ write_byte (FILE *file, Byte byte)
 void
 write_word (FILE *file, Word word)
 {
-  fwrite (&word, sizeof (Word), 1, file);
+#if (__BYTE_ORDER == __LITTLE_ENDIAN)
+   fwrite (&word, sizeof (Word), 1, file);
+#else
+  int i = 0;
+
+  while (i < sizeof (Word)) {
+    fputc (word & 0xff, file);
+    word >>= 8;
+    i++;
+  }
+#endif
 }
 
 void
 write_dword (FILE *file, DWord dword)
 {
+#if (__BYTE_ORDER == __LITTLE_ENDIAN)
   fwrite (&dword, sizeof (DWord), 1, file);
+#else
+  int i = 0;
+
+  while (i < sizeof (DWord)) {
+    fputc (dword & 0xff, file);
+    dword >>= 8;
+    i++;
+  }
+#endif
 }
 
 void
 write_long (FILE *file, Long long_val)
 {
+#if (__BYTE_ORDER == __LITTLE_ENDIAN)
   fwrite (&long_val, sizeof (Long), 1, file);
+#else
+  int i = 0;
+
+  while (i < sizeof (Long)) {
+    fputc (long_val & 0xff, file);
+    long_val >>= 8;
+    i++;
+  }
+#endif
 }
 
 int
@@ -218,7 +249,7 @@ color_convert (XpmColor *xpm_color, RGBQuad *wincolor)
   wincolor->rgbGreen = interp_color (char_ptr, clen);
   char_ptr += clen;
   wincolor->rgbBlue = interp_color (char_ptr, clen);
-  wincolor->rgbReserved = 0;  
+  wincolor->rgbReserved = 0;
 }
 
 void
@@ -352,7 +383,7 @@ is_valid_xpm_image (XpmImage *icon)
   if (icon->width != icon->height)
     {
       err_msg = "Image width or height are not equal.\n"
-	        "Can't currently scale image dimensions.";
+	"Can't currently scale image dimensions.";
       ret_code = EXIT_FAILURE;
     }
   else if (icon->width != 16
@@ -426,7 +457,7 @@ create_dir_entry (XpmImage *icon,
   else
     icon_dir_entry->dwBytesInRes =
       40 + icon_data->xor_size
-         + icon_data->and_size;
+      + icon_data->and_size;
 
   return icon_dir_entry;
 }
@@ -521,11 +552,11 @@ convert_color_map (XpmImage *icon, DWord ncolors)
       color_map = malloc (sizeof (ColorMap));
       color_map->nbr_colors = ncolors;
       color_map->color_list = malloc (sizeof (RGBQuad) * ncolors);
-      
+
       for (clr_count = 0 ; clr_count < icon->ncolors; clr_count++)
 	*(color_map->color_list + clr_count) =
 	  convert_color (icon->colorTable + clr_count);
-      
+
       if (!white_present (color_map))
 	{
 	  if (clr_count < ncolors)
@@ -580,7 +611,7 @@ put_8bit_color (DrawData *draw_data,
 
   ptr = draw_data->data
     + (draw_data->height - y - 1)
-       * draw_data->width
+    * draw_data->width
     + x;
 
   *ptr = val;
@@ -596,7 +627,7 @@ make_xor_mask (XpmImage *icon)
   DrawData *draw_data;
   Byte *mask;
 
-  bypp = bytes_per_pixel (icon->ncolors); 
+  bypp = bytes_per_pixel (icon->ncolors);
 
   mask_size = (DWord) icon->width * (DWord) icon->height * bypp;
 
@@ -617,10 +648,10 @@ make_xor_mask (XpmImage *icon)
 	    color = convert_color (icon->colorTable + *uint_ptr);
 	    put_24bit_color (draw_data, x, y, &color);
 	  }
-	
+
 	uint_ptr++;
       }
-  
+
   mask = draw_data->data;
   free (draw_data);
 
@@ -652,7 +683,7 @@ make_and_mask (XpmImage *icon, ColorMap *color_map)
 
 	if (color.rgbReserved)
 	  line[x / 8] |= 128 >> (x % 8);
-	
+
 	uint_ptr++;
       }
 
@@ -794,11 +825,11 @@ int convert_icon (char *ico_file_name,
       icon_data->and_mask = make_and_mask (icon,
 					   icon_data->color_map);
 
-      bypp = bytes_per_pixel (icon->ncolors);     
+      bypp = bytes_per_pixel (icon->ncolors);
 
       icon_data->xor_size = icon->width * icon->height * bypp;
       icon_data->and_size = ((icon->width+31)/32) * 4 * icon->height;
- 
+
       icon_data->icon_dir_entry =
 	create_dir_entry (icon, icon_data, ncolors);
       icon_data->header = new_icon_header ();
@@ -834,12 +865,12 @@ make_xpm_col_table (XpmImage *icon)
       else
 	ccount++;
     }
-  
+
   max_colors = ccount;
 
   xpm_col_codes = malloc (max_colors + 1);
   xpm_col_tbl_size = ccount;
- 
+
   for (ccount = 0; ccount < max_colors; ccount++)
     {
       cur_color = (icon->colorTable + ccount)->string;
@@ -923,7 +954,7 @@ process_icon (char *xpm_file_name, char *ico_file_name)
 	  perror (xpm_file_name);
 	  ret_code = EXIT_FAILURE;
 	}
-      
+
       free (icon);
       free (icon_info);
     }
@@ -942,7 +973,7 @@ deduce_ico_name (char *file_name)
   len = strlen (file_name);
   char_ptr = strrchr (file_name, '.');
 #ifdef __WIN32__
-  last_slash_ptr = strrchr (file_name, '\\');  
+  last_slash_ptr = strrchr (file_name, '\\');
 #else
   last_slash_ptr = strrchr (file_name, '/');
 #endif
@@ -998,9 +1029,9 @@ version ()
 void
 help ()
 {
-  printf ("This utility converts an xpm icon to a Windows ico file.\n");
-  printf ("%s [OPTIONS]... infile.xpm [outfile.ico]\n", PACKAGE);
-  printf ("\nOptional parameters:\n"
+  printf ("This utility converts an xpm icon to a Windows ico file.\n"
+	  PACKAGE " [OPTIONS]... infile.xpm [outfile.ico]\n"
+	  "\nOptional parameters:\n"
 	  "  -H, --help			display this help"
 	  " message\n"
 	  "  -f, --force			overwrite output"
@@ -1035,7 +1066,7 @@ int parse_args (int argc, char *argv[])
       { "verbose", 0, NULL, 'v' },
       { NULL, 0, NULL, 0 },
     };
-  
+
   stop_parsing = 0;
   ret_code = EXIT_SUCCESS;
 
@@ -1081,7 +1112,7 @@ int parse_args (int argc, char *argv[])
 	default:
 	  printf ("strange.\n");
 	  stop_parsing = 1;
-	  ret_code = EXIT_FAILURE;       
+	  ret_code = EXIT_FAILURE;
 	}
     }
 
